def getStats(vmanage, deviceId):
    """
    Get tcp proxy statistics from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tcpproxy/statistics?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatus(vmanage, deviceId):
    """
    Get tcp proxy status from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/tcpproxy/status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getSelfSignedCert(vmanage):
    """
    get self signed certificate
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/certificate/vmanage/selfsignedcert"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getProxyCertOfEdge(vmanage, deviceId):
    """
    Get edge proxy certificate
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/certificate?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def updateCert(vmanage, cert):
    """
    Upload device certificate
    
    Parameters:
    cert:	Upload device certificate
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/certificate"
    response = vmanage.apiCall("PUT", endpoint, cert)
    return response

def addWANEdge(vmanage, certstate, deviceId):
    """
    Add SSL proxy wan edge
    
    Parameters:
    certstate:	Cert state
	deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/certificate/wanedge/{deviceId}"
    response = vmanage.apiCall("POST", endpoint, certstate)
    return response

def uploadCerts(vmanage, certFile):
    """
    Upload device certificates
    
    Parameters:
    certFile:	Certificate file
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/certificates"
    response = vmanage.apiCall("POST", endpoint, certFile)
    return response

def getSslProxyCSR(vmanage, deviceId):
    """
    Get SSL proxy CSR
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/csr?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getAllDeviceCerts(vmanage, devicelist):
    """
    Get certificate for all cEdges
    
    Parameters:
    devicelist:	Device list
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/devicecertificates"
    response = vmanage.apiCall("POST", endpoint, devicelist)
    return response

def getAllDeviceCSR(vmanage, devicelist):
    """
    Get CSR for all cEdges
    
    Parameters:
    devicelist:	Device list
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/devicecsr"
    response = vmanage.apiCall("POST", endpoint, devicelist)
    return response

def generateSslProxyCSR(vmanage, csrRequest):
    """
    CSR request SSL proxy for edge
    
    Parameters:
    csrRequest:	CSR request for edge
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/generate/csr/sslproxy"
    response = vmanage.apiCall("POST", endpoint, csrRequest)
    return response

def generateSSLProxyCSR(vmanage, csrRequest):
    """
    Generate CSR
    
    Parameters:
    csrRequest:	CSR request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/generate/vmanage/csr"
    response = vmanage.apiCall("POST", endpoint, csrRequest)
    return response

def getSslProxyList(vmanage):
    """
    Get SSL proxy certificate list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/list"
    response = vmanage.apiCall("GET", endpoint)
    return response

def renewCert(vmanage, certRequest):
    """
    Renew device certificate
    
    Parameters:
    certRequest:	Renew device certificate request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/renew"
    response = vmanage.apiCall("POST", endpoint, certRequest)
    return response

def revokeCert(vmanage, certRequest):
    """
    Revoke device certificate
    
    Parameters:
    certRequest:	Revoke device certificate request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/revoke"
    response = vmanage.apiCall("POST", endpoint, certRequest)
    return response

def revokeRenewCert(vmanage, certRequest):
    """
    Revoke and renew device certificate
    
    Parameters:
    certRequest:	Revoke device certificate request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/revokerenew"
    response = vmanage.apiCall("POST", endpoint, certRequest)
    return response

def getCertState(vmanage):
    """
    Get certificate state
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/settings/certificate"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getEntCert(vmanage):
    """
    Get enterprise certificate
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/settings/enterprise/certificate"
    response = vmanage.apiCall("GET", endpoint)
    return response

def setEntCert(vmanage, certRequest):
    """
    Configure enterprise certificate
    
    Parameters:
    certRequest:	Config enterprise certificate request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/settings/enterprise/certificate"
    response = vmanage.apiCall("POST", endpoint, certRequest)
    return response

def getVManageEntRootCert(vmanage):
    """
    Get vManage enterprise root certificate
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/settings/enterprise/rootca"
    response = vmanage.apiCall("GET", endpoint)
    return response

def setEntRootCaCert(vmanage, certRequest):
    """
    Set vManage enterprise root certificate
    
    Parameters:
    setenterpriserootcarequest:	Set enterprise root CA request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/settings/enterprise/rootca"
    response = vmanage.apiCall("POST", endpoint, certRequest)
    return response

def getvManageCert(vmanage):
    """
    Get vManage intermediate certificate
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/settings/vmanage/certificate"
    response = vmanage.apiCall("GET", endpoint)
    return response

def setvManageintermediateCert(vmanage, certRequest):
    """
    Set vManage root certificate
    
    Parameters:
    certRequest:	Set vManage intermediate CA request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/settings/vmanage/certificate"
    response = vmanage.apiCall("POST", endpoint, certRequest)
    return response

def getvManageCSR(vmanage):
    """
    Get vManage CSR
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/settings/vmanage/csr"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getvManageRootCA(vmanage):
    """
    Get vManage root certificate
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/settings/vmanage/rootca"
    response = vmanage.apiCall("GET", endpoint)
    return response

def setvManageRootCA(vmanage, certRequest):
    """
    Set vManage root certificate
    
    Parameters:
    certRequest:	Set vManage root CA request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sslproxy/settings/vmanage/rootca"
    response = vmanage.apiCall("POST", endpoint, certRequest)
    return response



def createReplicatorList(vmanage, deviceId):
    """
    Get replicator list from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/multicast/replicator?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createRpfList(vmanage, deviceId):
    """
    Get RPF list from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/multicast/rpf?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createTopologyList(vmanage, deviceId):
    """
    Get topology list from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/multicast/topology?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createPimTunnelList(vmanage, deviceId):
    """
    Get PIM tunnel from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/multicast/tunnel?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def checkGivenIpList(vmanage, devicedetail):
    """
    Block IP based on list
    
    Parameters:
    devicedetail:	Device detail
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/software/compliance/ip/origin/check"
    response = vmanage.apiCall("POST", endpoint, devicedetail)
    return response



def getDBSchema(vmanage):
    """
    Get the current database schema
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/diagnostics/dbschema"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getThreadPools(vmanage):
    """
    Get information on the threadpools
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/diagnostics/threadpools"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatDataRawData(vmanage, query):
    """
    Get stats raw data
    
    Parameters:
    query	 (string):	Query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/speedtest?query={query}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatsRawData(vmanage, query):
    """
    Get stats raw data
    
    Parameters:
    query:	Stats query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/speedtest"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def getAggregationDataByQuery(vmanage, query):
    """
    Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
    
    Parameters:
    query	 (string):	Query filter
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/speedtest/aggregation?query={query}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getPostAggregationDataByQuery(vmanage, query):
    """
    Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
    
    Parameters:
    query:	Stats query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/speedtest/aggregation"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def getPostAggregationAppDataByQuery(vmanage, query):
    """
    Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
    
    Parameters:
    query:	Stats query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/speedtest/app-agg/aggregation"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def getStatDataRawDataAsCSV(vmanage, query):
    """
    Get raw data with optional query as CSV
    
    Parameters:
    query	 (string):	Query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/speedtest/csv?query={query}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getCount(vmanage, query):
    """
    Get response count of a query
    
    Parameters:
    query	 (string):	Query
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/speedtest/doccount?query={query}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getCountPost(vmanage, query):
    """
    Get response count of a query
    
    Parameters:
    query:	Query
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/speedtest/doccount"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def getStatDataFields(vmanage):
    """
    Get fields and type
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/speedtest/fields"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatBulkRawData(vmanage, query, scrollId, count):
    """
    Get stats raw data
    
    Parameters:
    query	 (string):	Query string
	scrollId	 (string):	ES scroll Id
	count	 (string):	Result size
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/speedtest/page?query={query}&scrollId={scrollId}&count={count}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getPostStatBulkRawData(vmanage, query, scrollId, count):
    """
    Get stats raw data
    
    Parameters:
    query:	Stats query string
	scrollId	 (string):	ES scroll Id
	count	 (string):	Result size
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/speedtest/page?scrollId={scrollId}&count={count}"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def getStatQueryFields(vmanage):
    """
    Get query fields
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/speedtest/query/fields"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSessionInfoCapture(vmanage, payload):
    """
    getSessionInfoCapture Description
    
    Parameters:
    payload:    Request Payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/capture"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response
def disablePacketCaptureSession(vmanage, sessionId):
    """
    disablePacketCaptureSession Description
    
    Parameters:
    sessionId  (string): Process uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/capture/disable/{sessionId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def downloadFile(vmanage, sessionId):
    """
    downloadFile Description
    
    Parameters:
    sessionId  (string): Process uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/capture/download/{sessionId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def forceStopPcapSession(vmanage, sessionId):
    """
    forceStopPcapSession Description
    
    Parameters:
    sessionId  (string): Process uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/capture/forcedisbale/{sessionId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def startPcapSession(vmanage, sessionId):
    """
    startPcapSession Description
    
    Parameters:
    sessionId  (string): Process uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/capture/start/{sessionId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getFileDownloadStatus(vmanage, sessionId):
    """
    getFileDownloadStatus Description
    
    Parameters:
    sessionId  (string): Process uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/capture/status/{sessionId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def stopPcapSession(vmanage, sessionId):
    """
    stopPcapSession Description
    
    Parameters:
    sessionId  (string): Process uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/capture/stop/{sessionId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def formPostPacketCapture(vmanage, deviceUUID, sessionId):
    """
    formPostPacketCapture Description
    
    Parameters:
    deviceUUID:     (string) Device uuid
	sessionId:      (string) Process uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/capture/{deviceUUID}/{sessionId}"
    response = vmanage.apiCall("POST", endpoint)
    return response
def getSessionInfoLog(vmanage, payload):
    """
    getSessionInfoLog Description
    
    Parameters:
    payload:    Request Payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/log"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response
def disableDeviceLog(vmanage, sessionId):
    """
    disableDeviceLog Description
    
    Parameters:
    sessionId	 (string):	Session Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/log/disable/{sessionId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def downloadDebugLog(vmanage, sessionId):
    """
    downloadDebugLog Description
    
    Parameters:
    sessionId  (string): Process uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/log/download/{sessionId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def renewSessionInfo(vmanage, sessionId):
    """
    renewSessionInfo Description
    
    Parameters:
    sessionId  (string): Process uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/log/renew/{sessionId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def searchDeviceLog(vmanage, payload, sessionId):
    """
    searchDeviceLog Description
    
    Parameters:
    payload:    Request Payload
	sessionId  (string): Process uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/log/search/{sessionId}"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response
def getSessions(vmanage):
    """
    getSessions Description
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/log/sessions"
    response = vmanage.apiCall("GET", endpoint)
    return response
def clearSession(vmanage, sessionId):
    """
    clearSession Description
    
    Parameters:
    sessionId  (string): Process uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/log/sessions/clear/{sessionId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getLogType(vmanage, uuid):
    """
    getLogType Description
    
    Parameters:
    uuid	 (string):	Device uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/log/type?uuid={uuid}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def streamLog(vmanage, payload, logType, deviceUUID, sessionId):
    """
    streamLog Description
    
    Parameters:
    payload:    Request Payload
	logType	 (string):	Log type
	deviceUUID	 (string):	Device uuid
	sessionId  (string): Process uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/log/{logType}/{deviceUUID}/{sessionId}"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response
def getDeviceLog(vmanage, sessionId, logId):
    """
    getDeviceLog Description
    
    Parameters:
    sessionId   (string): Process uuid
	logId       (string): log ID
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/log/{sessionId}?logId={logId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatDataRawData(vmanage, query):
    """
    Get stats raw data
    
    Parameters:
    query	 (string):	Query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi?query={query}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatsRawData(vmanage, query):
    """
    Get stats raw data
    
    Parameters:
    query:	Stats query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def getAggregationDataByQuery(vmanage, query):
    """
    Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
    
    Parameters:
    query	 (string):	Query filter
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/aggregation?query={query}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getPostAggregationDataByQuery(vmanage, query):
    """
    Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
    
    Parameters:
    query:	Stats query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/aggregation"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def getPostAggregationAppDataByQuery(vmanage, query):
    """
    Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
    
    Parameters:
    query:	Stats query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/app-agg/aggregation"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def getConcurrentData(vmanage, traceId, timestamp):
    """
    getConcurrentData Description
    
    Parameters:
    traceId	 (integer):	trace id
	timestamp	 (integer):	start time
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/concurrentData?traceId={traceId}&timestamp={timestamp}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getConcurrentDomainData(vmanage, traceId, timestamp):
    """
    getConcurrentDomainData Description
    
    Parameters:
    traceId	 (integer):	trace id
	timestamp	 (integer):	start time
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/concurrentDomainData?traceId={traceId}&timestamp={timestamp}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatDataRawDataAsCSV(vmanage, query):
    """
    Get raw data with optional query as CSV
    
    Parameters:
    query	 (string):	Query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/csv?query={query}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getCount(vmanage, query):
    """
    Get response count of a query
    
    Parameters:
    query	 (string):	Query
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/doccount?query={query}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getCountPost(vmanage, query):
    """
    Get response count of a query
    
    Parameters:
    query:	Query
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/doccount"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def getDomainMetric(vmanage, traceId, timestamp, domain, firstTimestamp, lastTimestamp):
    """
    getDomainMetric Description
    
    Parameters:
    traceId	 (integer):	trace id
	timestamp	 (integer):	start time
	domain	 (string):	domain name
	firstTimestamp	 (integer):	first timestamp of xAxis
	lastTimestamp	 (integer):	last timestamp of xAxis
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/domainMetric?traceId={traceId}&timestamp={timestamp}&domain={domain}&firstTimestamp={firstTimestamp}&lastTimestamp={lastTimestamp}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatDataFields(vmanage):
    """
    Get fields and type
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/fields"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getFinalizedData(vmanage, traceId, timestamp):
    """
    getFinalizedData Description
    
    Parameters:
    traceId	 (integer):	trace id
	timestamp	 (integer):	start time
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/finalizedData?traceId={traceId}&timestamp={timestamp}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getFinalizedDomainData(vmanage, traceId, timestamp):
    """
    getFinalizedDomainData Description
    
    Parameters:
    traceId	 (integer):	trace id
	timestamp	 (integer):	start time
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/finalizedDomainData?traceId={traceId}&timestamp={timestamp}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getFlowDetail(vmanage, traceId, timestamp, flowId):
    """
    getFlowDetail Description
    
    Parameters:
    traceId	 (integer):	trace id
	timestamp	 (integer):	start time
	flowId	 (integer):	flow id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/flowDetail?traceId={traceId}&timestamp={timestamp}&flowId={flowId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getFlowMetric(vmanage, traceId, timestamp, flowId, firstTimestamp, lastTimestamp):
    """
    getFlowMetric Description
    
    Parameters:
    traceId	 (integer):	trace id
	timestamp	 (integer):	start time
	flowId	 (integer):	flow id
	firstTimestamp	 (integer):	first timestamp of xAxis
	lastTimestamp	 (integer):	last timestamp of xAxis
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/flowMetric?traceId={traceId}&timestamp={timestamp}&flowId={flowId}&firstTimestamp={firstTimestamp}&lastTimestamp={lastTimestamp}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getMonitorState(vmanage, traceId, state):
    """
    getMonitorState Description
    
    Parameters:
    traceId	 (integer):	trace id
	state	 (string):	trace state
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/getMonitorState?traceId={traceId}&state={state}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def monitorStart(vmanage, payload):
    """
    CXP Monitor Action - Start
    
    Parameters:
    payload:    Request Payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/monitor/start"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response
def monitorStop(vmanage, payload):
    """
    CXP Monitor Action - Stop
    
    Parameters:
    payload:    Request Payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/monitor/stop"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response
def getNwpiDscp(vmanage):
    """
    getNwpiDscp Description
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/nwpiDSCP"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getNwpiNbarAppGroup(vmanage):
    """
    getNwpiNbarAppGroup Description
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/nwpiNbarAppGroup"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getNwpiProtocol(vmanage):
    """
    getNwpiProtocol Description
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/nwpiProtocol"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getPacketFeatures(vmanage, traceId, timestamp, flowId):
    """
    getPacketFeatures Description
    
    Parameters:
    traceId	 (integer):	trace id
	timestamp	 (integer):	start time
	flowId	 (integer):	flow id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/packetFeatures?traceId={traceId}&timestamp={timestamp}&flowId={flowId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatBulkRawData(vmanage, query, scrollId, count):
    """
    Get stats raw data
    
    Parameters:
    query	 (string):	Query string
	scrollId	 (string):	ES scroll Id
	count	 (string):	Result size
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/page?query={query}&scrollId={scrollId}&count={count}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getPostStatBulkRawData(vmanage, query, scrollId, count):
    """
    Get stats raw data
    
    Parameters:
    query:	Stats query string
	scrollId	 (string):	ES scroll Id
	count	 (string):	Result size
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/page?scrollId={scrollId}&count={count}"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def getStatQueryFields(vmanage):
    """
    Get query fields
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/query/fields"
    response = vmanage.apiCall("GET", endpoint)
    return response
def traceDelete(vmanage, traceId, timestamp):
    """
    Trace Action - Delete
    
    Parameters:
    traceId	 (string):	trace id
	timestamp	 (integer):	start time
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/trace/delete?traceId={traceId}&timestamp={timestamp}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response
def traceStart(vmanage, payload):
    """
    Trace Action - Start
    
    Parameters:
    payload:    Request Payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/trace/start"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response
def traceStop(vmanage, traceId):
    """
    Trace Action - Stop
    
    Parameters:
    Parameter Description
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/trace/stop/{traceId}"
    response = vmanage.apiCall("POST", endpoint)
    return response
def traceFinFlowWithQuery(vmanage, traceId, timestamp, query):
    """
    Retrieve Certain Fin Flows
    
    Parameters:
    traceId	 (integer):	trace id
	timestamp	 (integer):	start time
	query	 (string):	Query filter
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/traceFinFlowWithQuery?traceId={traceId}&timestamp={timestamp}&query={query}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getTraceFlow(vmanage, traceId, timestamp, state):
    """
    getTraceFlow Description
    
    Parameters:
    traceId	 (integer):	trace id
	timestamp	 (integer):	start time
	state	 (string):	trace state
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/traceFlow?traceId={traceId}&timestamp={timestamp}&state={state}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getTraceHistory(vmanage):
    """
    getTraceHistory Description
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/nwpi/traceHistory"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSession(vmanage, payload):
    """
    getSession Description
    
    Parameters:
    payload:    Request Payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/speed"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response
def disableSpeedTestSession(vmanage, sessionId):
    """
    disableSpeedTestSession Description
    
    Parameters:
    sessionId  (string): Process uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/speed/disable/{sessionId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getInterfaceBandwidth(vmanage, circuit, deviceUUID):
    """
    getInterfaceBandwidth Description
    
    Parameters:
    circuit     (string):   Circuit
	deviceUUID  (string):   Device ID
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/speed/interface/bandwidth?circuit={circuit}&deviceUUID={deviceUUID}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def startSpeedTest(vmanage, sessionId):
    """
    startSpeedTest Description
    
    Parameters:
    sessionId  (string): Process uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/speed/start/{sessionId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSpeedTestStatus(vmanage, sessionId):
    """
    getSpeedTestStatus Description
    
    Parameters:
    sessionId  (string): Process uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/speed/status/{sessionId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def stopSpeedTest(vmanage, sessionId):
    """
    stopSpeedTest Description
    
    Parameters:
    sessionId  (string): Process uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/speed/stop/{sessionId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def saveSpeedTestResults(vmanage, payload, deviceUUID, sessionId):
    """
    saveSpeedTestResults Description
    
    Parameters:
    payload:    Request Payload
	deviceUUID  (string):   Device ID
	sessionId  (string): Process uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/speed/{deviceUUID}/{sessionId}"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response
def getSpeedTest(vmanage, sessionId, logId):
    """
    getSpeedTest Description
    
    Parameters:
    sessionId  (string): Process uuid
	logId       (string): Log ID
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/speed/{sessionId}?logId={logId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def processDeviceStatus(vmanage, payload, deviceUUID):
    """
    Get device status stream
    
    Parameters:
    payload:    Request Payload
	deviceUUID	 (string):	Device uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/stream/device/status/{deviceUUID}"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response



def attach(vmanage, request):
    """
    Attach service chain to cluster
    
    Parameters:
    request:	Attach service chain request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/servicechain/attach"
    response = vmanage.apiCall("POST", endpoint, request)
    return response

def autoAttach(vmanage, request):
    """
    Attach service chain to cluster
    
    Parameters:
    request:	Attach service chain request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/servicechain/autoattach"
    response = vmanage.apiCall("POST", endpoint, request)
    return response

def detach(vmanage, request):
    """
    Detach service chain
    
    Parameters:
    request:	Detach service chain request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/servicechain/detach"
    response = vmanage.apiCall("PUT", endpoint, request)
    return response

def getEdgeDevices(vmanage):
    """
    Get edge devices
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/servicechain/edge/devices"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getpnfDevices(vmanage, pnfDeviceType):
    """
    Get PNF edge devices
    
    Parameters:
    pnfDeviceType	 (string):	PNF device type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/servicechain/edge/pnfdevices?pnfDeviceType={pnfDeviceType}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def createServerInfo(vmanage):
    """
    Get Server info
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/server/info"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getServiceChain(vmanage, serviceGroupName):
    """
    Get service chain by name
    
    Parameters:
    serviceGroupName	 (string):	Service group name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/servicegroup?serviceGroupName={serviceGroupName}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def update(vmanage, servicegroup):
    """
    Update service group
    
    Parameters:
    servicegroup:	Service group
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/servicegroup"
    response = vmanage.apiCall("PUT", endpoint, servicegroup)
    return response

def create(vmanage, servicegroup):
    """
    Add new service group
    
    Parameters:
    servicegroup:	Service group
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/servicegroup"
    response = vmanage.apiCall("POST", endpoint, servicegroup)
    return response

def getGroupInCluster(vmanage, ClusterId, UserGroupName):
    """
    Get service chains in cluster
    
    Parameters:
    ClusterId	 (string):	Cluster Id
	UserGroupName	 (string):	UserGroup Name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/servicegroup/attached?ClusterId={ClusterId}&UserGroupName={UserGroupName}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getDefaultChain(vmanage):
    """
    Get default service chains
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/servicegroup/servicechain/default"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getAvailableChains(vmanage):
    """
    Get all service chains
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/servicegroup/servicechains"
    response = vmanage.apiCall("GET", endpoint)
    return response

def delete(vmanage, name):
    """
    Delete service group
    
    Parameters:
    name	 (string):	Service group name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/colocation/servicegroup/{name}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response



def getInterfaceList(vmanage, deviceId):
    """
    Get PPPoE session list from device
    
    Parameters:
    Parameter Description
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/pppoe/session?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getNeighborList(vmanage, deviceId):
    """
    Get PPPoE statistics from device
    
    Parameters:
    Parameter Description
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/pppoe/statistic?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getPartners(vmanage):
    """
    Get all NMS partners
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getVPNList(vmanage):
    """
    Get all VPNs
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/vpn"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getPartnersByType(vmanage, partnerType):
    """
    Get NMS partners by partner type
    
    Parameters:
    partnerType	 (string):	Partner type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/{partnerType}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def registerPartner(vmanage, partner, partnerType):
    """
    Register NMS partner
    
    Parameters:
    partner:	Partner
	partnerType	 (string):	Partner type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/{partnerType}"
    response = vmanage.apiCall("POST", endpoint, partner)
    return response
def getPartnerDevices(vmanage, partnerType, nmsId):
    """
    List mapped devices for the partner
    
    Parameters:
    partnerType     (string):   Partner type
	nmsId	        (string):	NMS Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/{partnerType}/map/{nmsId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def mapDevices(vmanage, listofdevices, partnerType, nmsId):
    """
    Map devices for the partner
    
    Parameters:
    listofdevices:	            List of devices
	partnerType	    (string):	Partner type
	nmsId	        (string):	NMS Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/{partnerType}/map/{nmsId}"
    response = vmanage.apiCall("POST", endpoint, listofdevices)
    return response
def unmapDevices(vmanage, partnerType, nmsId):
    """
    Unmap all devices for the partner
    
    Parameters:
    partnerType     (string):   Partner type
	nmsId	        (string):	NMS Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/{partnerType}/map/{nmsId}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response
def deleteDeviceMapping(vmanage, listofdevices, partnerType, nmsId):
    """
    Unmap a set of devices for the partner
    
    Parameters:
    listofdevices:	List of devices
	partnerType	 (string):	Partner type
	nmsId	 (string):	NMS Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/{partnerType}/unmap/{nmsId}"
    response = vmanage.apiCall("POST", endpoint, listofdevices)
    return response
def getPartner(vmanage, partnerType, nmsId):
    """
    Get NMS partners by partner type and Id
    
    Parameters:
    partnerType	 (string):	Partner type
	nmsId	 (string):	NMS Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/{partnerType}/{nmsId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def updatePartner(vmanage, partner, partnerType, nmsId):
    """
    Update NMS partner details
    
    Parameters:
    partner:	                Partner
	partnerType	    (string):	Partner type
	nmsId	        (string):	NMS Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/{partnerType}/{nmsId}"
    response = vmanage.apiCall("PUT", endpoint, partner)
    return response
def deletePartner(vmanage, partnerType, nmsId):
    """
    Delete NMS partner
    
    Parameters:
    partnerType	    (string):	Partner type
	nmsId	        (string):	NMS Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/{partnerType}/{nmsId}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response
def getDataChangeInfo(vmanage, partnerId, event_id, eventNames, wait_time):
    """
    Retrieve registration change information
    
    Parameters:
    partnerId	 (string):	Partner Id
	event_id	 (string):	Continuation token of ongoing event-polling session
	eventNames	 (array):	Names of type of events to filter on
	wait_time	 (integer):	Maximum polling wait time in seconds
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/serverlongpoll/event/poll/{partnerId}?event_id={event_id}&eventNames={eventNames}&wait_time={wait_time}"
    response = vmanage.apiCall("GET", endpoint)
    return response



    
def getServers(vmanage, deviceId):
    """
    Get AAA servers from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/aaa/servers?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUsers(vmanage, deviceId):
    """
    Get AAA users from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/aaa/users?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getACLMatchCounterUsers(vmanage, deviceId):
    """
    Get ACL match counters from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/acl/matchcounter?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getLoggingFromDevice(vmanage, deviceId):
    """
    Get logging from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/logging?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUnclaimedVedges(vmanage, deviceId):
    """
    Get unclaimed vEdges from vbond
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/unclaimed/vedges?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUsersFromDevice(vmanage, deviceId):
    """
    Get users from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/users?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getAllDeviceUsers(vmanage, deviceId):
    """
    Get all users from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/users/list?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getQueueEntries(vmanage):
    """
    gets current on-demand queue entries
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/on-demand/queue"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createQueueEntry(vmanage, queue):
    """
    Create on-demand troubleshooting queue entry
    
    Parameters:
    queue:	On-demand queue entry
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/on-demand/queue"
    response = vmanage.apiCall("POST", endpoint, queue)
    return response
def getQueueProperties(vmanage):
    """
    gets current size of on-demand queue
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/on-demand/queue/properties"
    response = vmanage.apiCall("GET", endpoint)
    return response
def updateQueueEntry(vmanage, queue, entryId):
    """
    Updates on-demand troubleshooting queue entry
    
    Parameters:
    queue:	On-demand queue entry
	entryId	 (string):	Entry Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/on-demand/queue/{entryId}"
    response = vmanage.apiCall("PUT", endpoint, queue)
    return response
def deleteQueueEntry(vmanage, entryId):
    """
    removes on-demand queue entry
    
    Parameters:
    entryId	 (string):	Entry Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/on-demand/queue/{entryId}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response



from py_viptela.api.config.template import config
from py_viptela.api.config.template import design
from py_viptela.api.config.template import device
from py_viptela.api.config.template import general
from py_viptela.api.config.template import lock
from py_viptela.api.config.template import master
from py_viptela.api.config.template import security
from py_viptela.api.config.template import vedge
from py_viptela.api.config.template import voice
from py_viptela.api.config.template import vsmart


def getCoLineSpecificStats(vmanage, deviceId):
    """
    Get VDSL service line bonding stats from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/vdslService/coLineSpecificStats?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getCoStats(vmanage, deviceId):
    """
    Get CO stats from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/vdslService/coStats?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getCpeLineSpecificStats(vmanage, deviceId):
    """
    Get VDSL service CPE line specific stats from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/vdslService/cpeLineSpecificStats?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getCpeStats(vmanage, deviceId):
    """
    Get CPE stats from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/vdslService/cpeStats?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getLineBondingStats(vmanage, deviceId):
    """
    Get VDSL service line bonding stats from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/vdslService/lineBondingStats?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getLineSpecificStats(vmanage, deviceId):
    """
    Get VDSL service line specific stats from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/vdslService/lineSpecificStats?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getVdslInfo(vmanage, deviceId):
    """
    Get VDSL info from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/vdslService/vdslInfo?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getDefinitions(vmanage):
    """
    Get policy definitions
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/definition/ruleset"
    response = vmanage.apiCall("GET", endpoint)
    return response

def create(vmanage, policydefinition):
    """
    Create policy definition
    
    Parameters:
    policydefinition:	Policy definition
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/definition/ruleset"
    response = vmanage.apiCall("POST", endpoint, policydefinition)
    return response

def saveInBulk(vmanage, policydefinition):
    """
    Create/Edit policy definitions in bulk
    
    Parameters:
    policydefinition:	Policy definition
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/definition/ruleset/bulk"
    response = vmanage.apiCall("PUT", endpoint, policydefinition)
    return response

def editMultiple(vmanage, policydefinition, id):
    """
    Edit multiple policy definitions
    
    Parameters:
    policydefinition:	Policy definition
	id	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/definition/ruleset/multiple/{id}"
    response = vmanage.apiCall("PUT", endpoint, policydefinition)
    return response

def preview(vmanage, policydefinition):
    """
    Preview policy definition
    
    Parameters:
    policydefinition:	Policy definition
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/definition/ruleset/preview"
    response = vmanage.apiCall("POST", endpoint, policydefinition)
    return response

def previewById(vmanage, id):
    """
    Preview policy definition
    
    Parameters:
    id	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/definition/ruleset/preview/{id}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def get(vmanage, id):
    """
    Get a specific policy definitions
    
    Parameters:
    id	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/definition/ruleset/{id}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def edit(vmanage, policydefinition, id):
    """
    Edit a policy definitions
    
    Parameters:
    policydefinition:	Policy definition
	id	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/definition/ruleset/{id}"
    response = vmanage.apiCall("PUT", endpoint, policydefinition)
    return response

def delete(vmanage, id):
    """
    Delete policy definition
    
    Parameters:
    id	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/definition/ruleset/{id}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response



def getAssocs(vmanage, deviceId):
    """
    Get NTP peer associations list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ntp/associations?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getPeers(vmanage, deviceId):
    """
    Get NTP peer list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ntp/peer?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatus(vmanage, deviceId):
    """
    Get NTP status list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ntp/status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getTeList(vmanage, deviceId):
    """
    Get ThousandEyes app list from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/virtualApplication/te?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUtdList(vmanage, deviceId):
    """
    Get Utd apps list from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/virtualApplication/utd?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getWaasList(vmanage, deviceId):
    """
    Get Waas apps list from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/virtualApplication/waas?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



import pathlib
from setuptools import setup, find_packages

HERE = pathlib.Path(__file__).parent


VERSION = '0.2.9'
PACKAGE_NAME = 'py_viptela'
AUTHOR = 'Adem Atikturk'
AUTHOR_EMAIL = 'aatikturk@gmail.com'
URL = 'https://github.com/aatikturk/py_viptela'
LICENSE = 'GNU General Public License v2.0'
DESCRIPTION = 'A Python wrapper around Cisco vManage API'


LONG_DESCRIPTION = (HERE / "README.md").read_text()
LONG_DESC_TYPE = "text/markdown"

# Dependencies for the package
INSTALL_REQUIRES = [
      'requests'
]

# Python version requirement
PYTHON_REQUIRES = '>=3'

setup(name=PACKAGE_NAME,
      version=VERSION,
      description=DESCRIPTION,
      long_description=LONG_DESCRIPTION,
      long_description_content_type=LONG_DESC_TYPE,
      author=AUTHOR,
      license=LICENSE,
      author_email=AUTHOR_EMAIL,
      url=URL,
      install_requires=INSTALL_REQUIRES,
      python_requires=PYTHON_REQUIRES,
      py_modules = ['baseclient', 'reqs'],
      packages=find_packages()
      )



def getNetworkDesign(vmanage):
    """
    Get existing network design
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/networkdesign"
    response = vmanage.apiCall("GET", endpoint)
    return response

def editNetworkDesign(vmanage, payload, id):
    """
    Edit network segment
    
    Parameters:
    payload:	Network design payload
	id	 (string):	Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/networkdesign?id={id}"
    response = vmanage.apiCall("PUT", endpoint, payload)
    return response

def createNetworkDesign(vmanage, payload):
    """
    Create network design
    
    Parameters:
    payload:	Network design payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/networkdesign"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response

def pushNetworkDesign(vmanage, devicetemplate):
    """
    Attach network design
    
    Parameters:
    devicetemplate:	Device template
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/networkdesign/attachment"
    response = vmanage.apiCall("POST", endpoint, devicetemplate)
    return response

def getGlobalParams(vmanage):
    """
    Get global parameter templates
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/networkdesign/global/parameters"
    response = vmanage.apiCall("GET", endpoint)
    return response

def acquireEditLock(vmanage):
    """
    Acquire edit lock
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/networkdesign/lock/edit"
    response = vmanage.apiCall("POST", endpoint)
    return response

def runMyTest(vmanage, name):
    """
    Get all device templates for this feature template
    
    Parameters:
    name	 (string):	Test bane
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/networkdesign/mytest/{name}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def pushDeviceProfileTemplate(vmanage, devicetemplate, profileId):
    """
    Attach to device profile
    
    Parameters:
    devicetemplate:	Device template
	profileId	 (string):	Device profile Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/networkdesign/profile/attachment/{profileId}"
    response = vmanage.apiCall("POST", endpoint, devicetemplate)
    return response

def acquireAttachLock(vmanage, profileId):
    """
    Get the service profile config for a given device profile id
    
    Parameters:
    profileId	 (string):	Device profile Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/networkdesign/profile/lock/{profileId}"
    response = vmanage.apiCall("POST", endpoint)
    return response

def getConfigStatus(vmanage):
    """
    Get device profile configuration status
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/networkdesign/profile/status"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getConfigStatusById(vmanage, profileId):
    """
    Get device profile configuration status by profile Id
    
    Parameters:
    profileId	 (string):	Device profile Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/networkdesign/profile/status/{profileId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getTaskCount(vmanage):
    """
    Get device profile configuration task count
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/networkdesign/profile/task/count"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getTaskStatus(vmanage):
    """
    Get device profile configuration task status
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/networkdesign/profile/task/status"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getTaskStatusById(vmanage, profileId):
    """
    Get device profile configuration status by profile Id
    
    Parameters:
    profileId	 (string):	Device profile Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/networkdesign/profile/task/status/{profileId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getServiceProfileConfig(vmanage, profileId, deviceModel):
    """
    Get the service profile config for a given device profile id
    
    Parameters:
    profileId	 (string):	Device profile Id
	deviceModel	 (string):	Device model
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/networkdesign/serviceProfileConfig/{profileId}?deviceModel={deviceModel}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getNeighbors(vmanage, vpnId, peerAddr, asNo, deviceId):
    """
    Get BGP neighbors list (Real Time)
    
    Parameters:
    vpnId	 (string):	VPN Id
	peerAddr	 (string):	Peer address
	asNo	 (string):	AS number
	deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/bgp/neighbors?vpnId={vpnId}&peerAddr={peerAddr}&as={asNo}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createBGPRoutesList(vmanage, vpnId, prefix, nexthop, deviceId):
    """
    Get BGP routes list (Real Time)
    
    Parameters:
    vpnId	 (string):	VPN Id
	prefix	 (string):	IP prefix
	nexthop	 (string):	Next hop
	deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/bgp/routes?vpnId={vpnId}&prefix={prefix}&nexthop={nexthop}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createBGPSummary(vmanage, deviceId):
    """
    Get BGP summary (Real Time)
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/bgp/summary?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getDPIDeviceFieldJSON(vmanage, isDeviceDashBoard):
    """
    Get DPI query field from device
    
    Parameters:
    isDeviceDashBoard	 (boolean):	Flag whether is device dashboard request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/dpi/application/fields?isDeviceDashBoard={isDeviceDashBoard}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createDPICollectorList(vmanage, vpnId, application, family, deviceId):
    """
    Get DPI applications from device (Real Time)
    
    Parameters:
    vpnId	 (string):	VPN Id
	application	 (string):	Application
	family	 (string):	Family
	deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/dpi/applications?vpn-id={vpnId}&application={application}&family={family}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getCommonAppList(vmanage):
    """
    Get DPI common application list from device
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/dpi/common/applications"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDPIFieldJSON(vmanage):
    """
    Get DPI field from device
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/dpi/device/fields"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDPIDeviceDetailsFieldJSON(vmanage):
    """
    Get DPI detailed field from device
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/dpi/devicedetails/fields"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDPIFlowsList(vmanage, vpnId, ip, application, family, deviceId):
    """
    Get DPI flow list from device (Real Time)
    
    Parameters:
    vpnId	            (string):	VPN Id
	ip	                (string):	Source IP
	application	        (string):	Application
	family	            (string):	Family
	deviceId	        (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/dpi/flows?vpn-id={vpnId}&src-ip={ip}&application={application}&family={family}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getQosmosAppList(vmanage):
    """
    Get DPI QoSMos application list from device
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/dpi/qosmos/applications"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDPISummaryRealTime(vmanage, deviceId):
    """
    Get DPI summary from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/dpi/summary?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDPIStatistics(vmanage, application, family, deviceId):
    """
    Get supported applications from device (Real Time)
    
    Parameters:
    application	 (string):	Application
	family	 (string):	Family
	deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/dpi/supported-applications?application={application}&family={family}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response


def checkIfClusterLocked(vmanage):
    """
    Check whether cluster is locked
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/clusterManagement/clusterLocked"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getClusterWorkflowVersion(vmanage):
    """
    List vManages in the cluster
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/clusterManagement/clusterworkflow/version"
    response = vmanage.apiCall("GET", endpoint)
    return response
def configureVmanage(vmanage, vmanageConfig):
    """
    Configure vManage
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    vmanageConfig:	vManage server config
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/clusterManagement/configure"
    response = vmanage.apiCall("POST", endpoint, vmanageConfig)
    return response
def getConnectedDevices(vmanage, vmanageIP):
    """
    Get connected device for vManage
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    vmanageIP	 (string):	vManage IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/clusterManagement/connectedDevices/{vmanageIP}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def healthDetails(vmanage):
    """
    Get cluster health check details
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/clusterManagement/health/details"
    response = vmanage.apiCall("GET", endpoint)
    return response
def healthStatusInfo(vmanage):
    """
    Get cluster health check details
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/clusterManagement/health/status"
    response = vmanage.apiCall("GET", endpoint)
    return response
def healthSummary(vmanage, isCached):
    """
    Get cluster health check summary
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    isCached	 (boolean):	Flag to enable cached result
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/clusterManagement/health/summary?isCached={isCached}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getConfiguredIPList(vmanage, vmanageID):
    """
    Get configured IP addresses
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    vmanageID	 (string):	vManage Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/clusterManagement/iplist/{vmanageID}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def isClusterReady(vmanage):
    """
    Is cluster ready
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/clusterManagement/isready"
    response = vmanage.apiCall("GET", endpoint)
    return response
def listVmanages(vmanage):
    """
    List vManages in the cluster
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/clusterManagement/list"
    response = vmanage.apiCall("GET", endpoint)
    return response
def nodeProperties(vmanage):
    """
    Get properties of vManage being added to  cluster
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/clusterManagement/nodeProperties"
    response = vmanage.apiCall("GET", endpoint)
    return response
def removeVmanage(vmanage, vmanageInfo):
    """
    Remove vManage from cluster
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    vmanageInfo:	vManage server info
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/clusterManagement/remove"
    response = vmanage.apiCall("POST", endpoint, vmanageInfo)
    return response
def performReplicationAndRebalanceOfKafkaPartitions(vmanage):
    """
    Initiate replication and rebalance of kafka topics
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/clusterManagement/replicateAndRebalance"
    response = vmanage.apiCall("PUT", endpoint)
    return response
def editVmanage(vmanage, clusterConfig):
    """
    Update vManage cluster info
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    clusterConfig:	vManage cluster config
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/clusterManagement/setup"
    response = vmanage.apiCall("PUT", endpoint, clusterConfig)
    return response
def addVmanage(vmanage, clusterConfig):
    """
    Add vManage to cluster
    
    Parameters:
    clusterConfig:	vManage cluster config
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/clusterManagement/setup"
    response = vmanage.apiCall("POST", endpoint, clusterConfig)
    return response
def getTenancyMode(vmanage):
    """
    Get vManage tenancy mode
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/clusterManagement/tenancy/mode"
    response = vmanage.apiCall("GET", endpoint)
    return response
def setTenancyMode(vmanage, tenancySetting):
    """
    Update vManage tenancy mode
    
    Parameters:
    tenancySetting:	Tenancy mode setting
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/clusterManagement/tenancy/mode"
    response = vmanage.apiCall("POST", endpoint, tenancySetting)
    return response
def getTenantsList(vmanage):
    """
    Get tenant list
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/clusterManagement/tenantList"
    response = vmanage.apiCall("GET", endpoint)
    return response
def addOrUpdateUserCredentials(vmanage, creds):
    """
    Add or update user credentials for cluster operations
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    creds:	User credential
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/clusterManagement/userCreds"
    response = vmanage.apiCall("POST", endpoint, creds)
    return response
def getVManageDetails(vmanage, vmanageIP):
    """
    Get vManage detail
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    vmanageIP	 (string):	vManage IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/clusterManagement/vManage/details/{vmanageIP}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getConnectedDevicesPerTenant(vmanage, tenantId, vmanageIP):
    """
    Get connected device for vManage for a tenant
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    tenantId	 (string):	Tenant Id
	vmanageIP	 (string):	vManage IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/clusterManagement/{tenantId}/connectedDevices/{vmanageIP}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getCloudConnector(vmanage):
    """
    Get SD_AVC Cloud Connector Config
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sdavc/cloudconnector"
    response = vmanage.apiCall("GET", endpoint)
    return response
def disableCloudConnector(vmanage, payload):
    """
    Disable SD_AVC Cloud Connector
    
    Parameters:
    payload:	Request Payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sdavc/cloudconnector"
    response = vmanage.apiCall("PUT", endpoint, payload)
    return response
def enableCloudConnector(vmanage, payload):
    """
    Enable SD_AVC Cloud Connector
    
    Parameters:
    payload:	Request Payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sdavc/cloudconnector"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response
def getCloudConnectorStatus(vmanage):
    """
    Get SD_AVC Cloud Connector Status
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sdavc/cloudconnector/status"
    response = vmanage.apiCall("GET", endpoint)
    return response



def onboardMDP(vmanage, onboard):
    """
    Start MDP onboarding operation
    
    Parameters:
    onboard:	Onboard
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/mdp/onboard"
    response = vmanage.apiCall("POST", endpoint, onboard)
    return response

def getOnboardStatus(vmanage):
    """
    Get MDP onboarding status
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/mdp/onboard/status"
    response = vmanage.apiCall("GET", endpoint)
    return response

def updateOnboardingPayload(vmanage, onboard, nmsId):
    """
    update MDP onboarding document
    
    Parameters:
    onboard:	Onboard
	Parameter Description
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/mdp/onboard/{nmsId}"
    response = vmanage.apiCall("PUT", endpoint, onboard)
    return response
